@@ -66,6 +66,9 @@
 #'   from building files. It will be created if necessary and ignored if
 #'   \code{local = TRUE}. The default is to use a directory named
 #'   \code{workflowr} in \code{\link{tempdir}}.
+#' @param verbose logical (default: FALSE). Display the build log directly in
+#'   the R console as each file is built. This is useful for monitoring
+#'   long-running code chunks.
 #' @param local logical (default: FALSE). Build files locally in the R console.
 #'   This should only be used for debugging purposes. The default is to build
 #'   each file in its own separate fresh R process to ensure each file is
@@ -94,6 +97,8 @@
 #'
 #'    \item \bold{log_dir}: The directory where the log files were saved
 #'
+#'    \item \bold{verbose}: The input argument \code{verbose}
+#'
 #'    \item \bold{local}: The input argument \code{local}
 #'
 #'    \item \bold{dry_run}: The input argument \code{dry_run}
@@ -127,7 +132,7 @@
 #' @export
 wflow_build <- function(files = NULL, make = is.null(files),
                         update = FALSE, republish = FALSE, view = interactive(),
-                        seed = 12345, log_dir = NULL,
+                        seed = 12345, log_dir = NULL, verbose = FALSE,
                         local = FALSE, dry_run = FALSE, project = ".") {
 
   # Check input arguments ------------------------------------------------------
@@ -172,6 +177,9 @@ wflow_build <- function(files = NULL, make = is.null(files),
   log_dir <- absolute(log_dir)
   dir.create(log_dir, showWarnings = FALSE, recursive = TRUE)
 
+  if (!(is.logical(verbose) && length(verbose) == 1))
+    stop("verbose must be a one-element logical vector")
+
   if (!(is.logical(local) && length(local) == 1))
     stop("local must be a one-element logical vector")
 
@@ -247,9 +255,15 @@ wflow_build <- function(files = NULL, make = is.null(files),
       if (local) {
         build_rmd(f, seed = seed, envir = .GlobalEnv)
       } else {
-        build_rmd_external(f, seed = seed, log_dir = log_dir, envir = .GlobalEnv)
+        build_rmd_external(f, seed = seed, log_dir = log_dir, verbose = verbose,
+                           envir = .GlobalEnv)
       }
     }
+    # Create .nojekyll if it doesn't exist
+    nojekyll <- file.path(p$docs, ".nojekyll")
+    if (!file.exists(nojekyll)) {
+      file.create(nojekyll)
+    }
   }
 
   # View files -----------------------------------------------------------------
@@ -273,7 +287,7 @@ wflow_build <- function(files = NULL, make = is.null(files),
 
   o <- list(files = files, make = make,
             update = update, republish = republish, view = view,
-            seed = seed, log_dir = log_dir,
+            seed = seed, log_dir = log_dir, verbose = verbose,
             local = local, dry_run = dry_run,
             built = files_to_build,
             html = to_html(files_to_build, outdir = p$docs))
@@ -344,7 +358,7 @@ return_modified_rmd <- function(rmd_files, docs) {
   return(files_to_update)
 }
 
-build_rmd_external <- function(rmd, seed, log_dir, ...) {
+build_rmd_external <- function(rmd, seed, log_dir, verbose = FALSE, ...) {
   if (!(is.character(rmd) && length(rmd) == 1))
     stop("rmd must be a one element character vector")
   if (!file.exists(rmd))
@@ -368,7 +382,8 @@ build_rmd_external <- function(rmd, seed, log_dir, ...) {
     callr::r_safe(build_rmd,
                   args = list(rmd, seed, ...),
                   stdout = stdout_file,
-                  stderr = stderr_file),
+                  stderr = stderr_file,
+                  show = verbose),
     error = function(e) {
       message(wrap("Build failed. See log files for full details."))
       message("stdout: ", stdout_file)
