@@ -86,6 +86,47 @@ test_that("A warning does not cause any problem", {
   expect_true(file.exists("_site/warning.html"))
 })
 
+test_that("verbose displays build log directly in R console", {
+
+  skip_on_cran()
+
+  on.exit(unlink(l, recursive = TRUE, force = TRUE))
+  dir.create(l)
+
+  observed <- utils::capture.output(
+    build_rmd_external("warning.Rmd", seed = 1, log_dir = l, verbose = TRUE))
+  # Remove extraneous characters surrounded by \r from console output
+  observed <- stringr::str_replace_all(observed, "\r.\r", "")
+  os <- Sys.info()["sysname"]
+  # Remove trailing \r (only observed on Windows)
+  if (os == "Windows") {
+    observed <- stringr::str_replace_all(observed, "\r$", "")
+  }
+  # Remove extraneous \r pairs with many characters in-between (only observed on
+  # macOS)
+  if (os == "Darwin") {
+    observed <- stringr::str_replace_all(observed, "\r", "")
+  }
+  expected_stdout <- readLines(Sys.glob(file.path(l, "warning.Rmd-*out.txt")))
+  expected_stderr <- readLines(Sys.glob(file.path(l, "warning.Rmd-*err.txt")))
+  # Confirm that chunk labels were sent to R console
+  expect_identical(observed[stringr::str_detect(observed, "^label:")],
+                   expected_stdout[stringr::str_detect(expected_stdout, "^label:")])
+  # Confirm that pandoc line was sent to R console
+  expect_identical(observed[stringr::str_detect(observed, "pandoc")],
+                   expected_stdout[stringr::str_detect(expected_stdout, "pandoc")])
+
+  # For some strange reason, the standard error line is not sent to the R
+  # console only on the Travis macOS (10.12.6) build with r-oldrel (R 3.3.3) and
+  # rmarkdown 1.8. I could not replicate this using macOS 10.10.5, R 3.3.3, and
+  # rmarkdown 1.8.
+  skip_on_travis()
+
+  # Confirm that "Output created:" line was sent to R console
+  expect_identical(observed[stringr::str_detect(observed, "Output created:")],
+                   expected_stderr[stringr::str_detect(expected_stderr, "Output created:")])
+})
+
 # Test error handling ----------------------------------------------------------
 
 test_that("rmd is valid", {
